aboutsummaryrefslogtreecommitdiff
path: root/classes/PhpIsisDb.php
diff options
context:
space:
mode:
Diffstat (limited to 'classes/PhpIsisDb.php')
-rw-r--r--classes/PhpIsisDb.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/classes/PhpIsisDb.php b/classes/PhpIsisDb.php
index 03e9b7c..aa1c239 100644
--- a/classes/PhpIsisDb.php
+++ b/classes/PhpIsisDb.php
@@ -69,11 +69,11 @@ class PhpIsisDb implements IsisDb {
}
/**
* Return number of rows in the database.
*
- * @see IsisDb::rows()
+ * @see IsisDb::entries()
*/
- public function rows() {
+ public function entries() {
return isis_last_mfn($this->db);
}
@@ -69,11 +69,11 @@ class PhpIsisDb implements IsisDb {
}
/**
- * Return number of rows in the database.
+ * Return number of entries in the database.
*